@@ -3,7 +3,7 @@ use strict;
 use warnings;
 use base qw(Exporter);
 
-our @EXPORT_OK = qw(check_config_script check_prebuilt_binaries check_src_build find_SDL_dir find_file check_header sed_inplace);
+our @EXPORT_OK = qw(check_config_script check_prebuilt_binaries check_src_build find_SDL_dir find_file check_header sed_inplace get_dlext);
 use Config;
 use ExtUtils::CBuilder;
 use File::Spec::Functions qw(splitdir catdir splitpath catpath rel2abs);
@@ -582,6 +582,10 @@ sub check_prereqs_libs {
     my $inc_lib_candidates = {
       '/usr/local/include' => '/usr/local/lib',
       '/usr/include'       => '/usr/lib',
+      '/usr/include'       => '/usr/lib32',
+      '/usr/include'       => '/usr/lib64',
+      '/include'       	   => '/lib',
+
     };
     my $header_map         = {
       'z'    => 'zlib',
@@ -589,10 +593,11 @@ sub check_prereqs_libs {
     };
     my $header             = (defined $header_map->{$lib}) ? $header_map->{$lib} : $lib;
 
+    my $dlext = get_dlext();
     foreach (keys %$inc_lib_candidates) {
       my $ld = $inc_lib_candidates->{$_};
       next unless -d $_ && -d $ld;
-      ($found_lib) = find_file($ld, qr/[\/\\]lib\Q$lib\E[\-\d\.]*\.\Q$Config{dlext}\E[\d\.]*$/);
+      ($found_lib) = find_file($ld, qr/[\/\\]lib\Q$lib\E[\-\d\.]*\.$dlext[\d\.]*$/);
       ($found_inc) = find_file($_,  qr/[\/\\]\Q$header\E[\-\d\.]*\.h$/);
       last if $found_lib && $found_inc;
     }
@@ -716,4 +721,13 @@ sub sed_inplace {
   }
 }
 
+sub get_dlext {
+  if($^O =~ /darwin/) { # there can be .dylib's on a mac even if $Config{dlext} is 'bundle'
+    return 'so|dylib|bundle';
+  }
+  else {
+    return $Config{dlext};
+  }
+}
+
 1;
